@@ -57,6 +57,7 @@ def _explore(
     tooltip_kwds={},
     popup_kwds={},
     legend_kwds={},
+    map_kwds={},
     **kwargs,
 ):
     """Interactive map based on GeoPandas and folium/leaflet.js
@@ -182,6 +183,16 @@ def _explore(
             Fill color. Defaults to the value of the color option
         fillOpacity : float (default 0.5)
             Fill opacity.
+        style_function : callable
+            Function mapping a GeoJson Feature to a style ``dict``.
+
+            * Style properties :func:`folium.vector_layers.path_options`
+            * GeoJson features :class:`GeoDataFrame.__geo_interface__`
+
+            e.g.::
+
+                lambda x: {"color":"red" if x["properties"]["gdp_md_est"]<10**6
+                                             else "blue"}
 
         Plus all supported by :func:`folium.vector_layers.path_options`. See the
         documentation of :class:`folium.features.GeoJson` for details.
@@ -225,6 +236,10 @@ def _explore(
             Applies if ``colorbar=False``.
         max_labels : int, default 10
             Maximum number of colorbar tick labels (requires branca>=0.5.0)
+    map_kwds : dict (default {})
+        Additional keywords to be passed to folium :class:`~folium.folium.Map`,
+        e.g. ``dragging``, or ``scrollWheelZoom``.
+
 
     **kwargs : dict
         Additional options to be passed on to the folium object.
@@ -302,7 +317,16 @@ GON (((180.00000 -16.06713, 180.00000...
             fit = False
 
         # get a subset of kwargs to be passed to folium.Map
-        map_kwds = {i: kwargs[i] for i in kwargs.keys() if i in _MAP_KWARGS}
+        for i in _MAP_KWARGS:
+            if i in map_kwds:
+                raise ValueError(
+                    f"'{i}' cannot be specified in 'map_kwds'. "
+                    f"Use the '{i}={map_kwds[i]}' argument instead."
+                )
+        map_kwds = {
+            **map_kwds,
+            **{i: kwargs[i] for i in kwargs.keys() if i in _MAP_KWARGS},
+        }
 
         if HAS_XYZSERVICES:
             # match provider name string to xyzservices.TileProvider
@@ -353,7 +377,11 @@ GON (((180.00000 -16.06713, 180.00000...
                     "Cannot specify 'categories' when column has categorical dtype"
                 )
             categorical = True
-        elif gdf[column].dtype is np.dtype("O") or categories:
+        elif (
+            gdf[column].dtype is np.dtype("O")
+            or gdf[column].dtype is np.dtype(bool)
+            or categories
+        ):
             categorical = True
 
         nan_idx = pd.isna(gdf[column])
@@ -430,6 +458,17 @@ GON (((180.00000 -16.06713, 180.00000...
         style_kwds["fillOpacity"] = 0.5
     if "weight" not in style_kwds:
         style_kwds["weight"] = 2
+    if "style_function" in style_kwds:
+        style_kwds_function = style_kwds["style_function"]
+        if not callable(style_kwds_function):
+            raise ValueError("'style_function' has to be a callable")
+        style_kwds.pop("style_function")
+    else:
+
+        def _no_style(x):
+            return {}
+
+        style_kwds_function = _no_style
 
     # specify color
     if color is not None:
@@ -440,10 +479,14 @@ GON (((180.00000 -16.06713, 180.00000...
         ):  # use existing column
 
             def _style_color(x):
-                return {
+                base_style = {
                     "fillColor": x["properties"][color],
                     **style_kwds,
                 }
+                return {
+                    **base_style,
+                    **style_kwds_function(x),
+                }
 
             style_function = _style_color
         else:  # assign new column
@@ -462,27 +505,35 @@ GON (((180.00000 -16.06713, 180.00000...
             if not stroke_color:
 
                 def _style_column(x):
-                    return {
+                    base_style = {
                         "fillColor": x["properties"]["__folium_color"],
                         "color": x["properties"]["__folium_color"],
                         **style_kwds,
                     }
+                    return {
+                        **base_style,
+                        **style_kwds_function(x),
+                    }
 
                 style_function = _style_column
             else:
 
                 def _style_stroke(x):
-                    return {
+                    base_style = {
                         "fillColor": x["properties"]["__folium_color"],
                         "color": stroke_color,
                         **style_kwds,
                     }
+                    return {
+                        **base_style,
+                        **style_kwds_function(x),
+                    }
 
                 style_function = _style_stroke
     else:  # use folium default
 
         def _style_default(x):
-            return {**style_kwds}
+            return {**style_kwds, **style_kwds_function(x)}
 
         style_function = _style_default
 
@@ -526,7 +577,7 @@ GON (((180.00000 -16.06713, 180.00000...
         ]
         gdf = gdf.drop(columns=non_active_geoms)
 
-    # preprare tooltip and popup
+    # prepare tooltip and popup
     if isinstance(gdf, geopandas.GeoDataFrame):
         # add named index to the tooltip
         if gdf.index.name is not None:
@@ -796,6 +847,7 @@ def _explore_geoseries(
     marker_kwds={},
     style_kwds={},
     highlight_kwds={},
+    map_kwds={},
     **kwargs,
 ):
     """Interactive map based on GeoPandas and folium/leaflet.js
@@ -866,6 +918,17 @@ def _explore_geoseries(
             Fill color. Defaults to the value of the color option
         fillOpacity : float (default 0.5)
             Fill opacity.
+        style_function : callable
+            Function mapping a GeoJson Feature to a style ``dict``.
+
+            * Style properties :func:`folium.vector_layers.path_options`
+            * GeoJson features :class:`GeoSeries.__geo_interface__`
+
+            e.g.::
+
+                lambda x: {"color":"red" if x["properties"]["gdp_md_est"]<10**6
+                                             else "blue"}
+
 
         Plus all supported by :func:`folium.vector_layers.path_options`. See the
         documentation of :class:`folium.features.GeoJson` for details.
@@ -873,6 +936,9 @@ def _explore_geoseries(
     highlight_kwds : dict (default {})
         Style to be passed to folium highlight_function. Uses the same keywords
         as ``style_kwds``. When empty, defaults to ``{"fillOpacity": 0.75}``.
+    map_kwds : dict (default {})
+        Additional keywords to be passed to folium :class:`~folium.folium.Map`,
+        e.g. ``dragging``, or ``scrollWheelZoom``.
 
     **kwargs : dict
         Additional options to be passed on to the folium.
@@ -897,5 +963,6 @@ def _explore_geoseries(
         marker_kwds=marker_kwds,
         style_kwds=style_kwds,
         highlight_kwds=highlight_kwds,
+        map_kwds=map_kwds,
         **kwargs,
     )
